Learn R Programming

WRI (version 0.2.1)

WARp_acvfs: Function for calculating sample Wasserstein autocovariance functions

Description

This function uses a time series of quantile functions to calculate the sample Wasserstein autocovariance functions from order \(0\) to \(p\) with a specified training window

Usage

WARp_acvfs(end.day, training.size, quantile, quantile.grid, p)

Value

A list with

  • acvfs - The sample Wasserstein autocovariance functions from order \(0\) to \(p\)

  • barycenter - The sample average of the quantile functions in the training window

  • quantile.pred - The quantile functions from \(end.day - p + 1\) to \(end.day\)

Arguments

end.day

A positive integer, the last index of the training window.

training.size

A positive integer, the size of the training widnows.

quantile

A matrix containing all the available quantile functions. Columns represent time indices and rows represent evaluation grid.

quantile.grid

A numeric vector, the grid over which quantile functions are evaluated.

p

A positive integer, the maximum order of the sample Wasserstein autocovariance functions.