Learn R Programming

WRI (version 0.2.1)

WARp_forecast_tangent: Forecast using WAR(p) models

Description

This is a simplified function that produces the one-step ahead forecasts from WAR(p) models in the tangent space

Usage

WARp_forecast_tangent(p, acvfs)

Value

A numeric vector, the one-step ahead forecast produced by the WAR(p) model in the tangent space.

Arguments

p

A positive integer, the order of the WAR(p) model.

acvfs

A list that is the output of WARp_acvfs()

References

Wasserstein Autoregressive Models for Density Time Series, Chao Zhang, Piotr Kokoszka, Alexander Petersen, 2022