globalFstat: An internal function used in bootstrap global F test

View source: R/globalFstat.R

globalFstatR Documentation

An internal function used in bootstrap global F test

Description

An internal function used in bootstrap global F test

quick wasserstein regression fitting function with smoothed input

Usage

globalFstat(xfit, Qobs, t_vec)

short_wass_regress(Xfit_df, smoothY)

WRI documentation built on March 29, 2026, 1:06 a.m.