Learn R Programming

WRI (version 0.2.1)

quan2den_qd: convert density function to quantile and quantile density function

Description

convert density function to quantile and quantile density function

Usage

quan2den_qd(quantileCurves, t_vec)

Arguments

quantileCurves

n-by-m matrix of quantile curves

t_vec

length m vector contains the common support grid of the quantile curves