This function uses a time series of quantile functions to calculate the sample Wasserstein autocovariance functions from order \(0\) to \(p\) with a specified training window
WARp_acvfs(end.day, training.size, quantile, quantile.grid, p)A list with
acvfs - The sample Wasserstein autocovariance functions from order \(0\) to \(p\)
barycenter - The sample average of the quantile functions in the training window
quantile.pred - The quantile functions from \(end.day - p + 1\) to \(end.day\)
A positive integer, the last index of the training window.
A positive integer, the size of the training widnows.
A matrix containing all the available quantile functions. Columns represent time indices and rows represent evaluation grid.
A numeric vector, the grid over which quantile functions are evaluated.
A positive integer, the maximum order of the sample Wasserstein autocovariance functions.