This is a simplified function that produces the one-step ahead forecasts from WAR(p) models in the tangent space
WARp_forecast_tangent(p, acvfs)A numeric vector, the one-step ahead forecast produced by the WAR(p) model in the tangent space.
A positive integer, the order of the WAR(p) model.
A list that is the output of WARp_acvfs()
Wasserstein Autoregressive Models for Density Time Series, Chao Zhang, Piotr Kokoszka, Alexander Petersen, 2022